@@ -529,7 +529,7 @@ class Kibm(object):
             return None
         return vm['primary_network_interface']['primary_ipv4_address']
 
-    def volumes(self, iso=False):
+    def volumes(self, iso=False, extended=False):
         image_list = []
         try:
             images = self.conn.list_images().result['images']
@@ -969,7 +969,7 @@ class Kibm(object):
                             internal=False, dnsclient=None, ip=None):
 
         ports = [int(port) for port in ports]
-        internal = False if internal is None else internal
+        internal = internal or False
         clean_name = name.replace('.', '-')
         pprint(f"Creating Security Group {clean_name}")
         security_group_ports = ports + [int(checkport)] if int(checkport) not in ports else ports
